using System;
using Cpp2IlInjected;
using UnityEngine;

// Token: 0x020002F2 RID: 754
[Token(Token = "0x20002F2")]
[Serializable]
public class NobetaConfigData
{
	// Token: 0x17000161 RID: 353
	// (get) Token: 0x06001CB4 RID: 7348 RVA: 0x000449A4 File Offset: 0x00042BA4
	[Token(Token = "0x17000161")]
	public int AirAttackIndex
	{
		[Token(Token = "0x6001CB4")]
		[Address(RVA = "0x4179A0", Offset = "0x4167A0", VA = "0x1804179A0")]
		get
		{
			return this.airAttackIndex;
		}
	}

	// Token: 0x06001CB5 RID: 7349 RVA: 0x000449B8 File Offset: 0x00042BB8
	[Token(Token = "0x6001CB5")]
	[Address(RVA = "0xECCBB0", Offset = "0xECB9B0", VA = "0x180ECCBB0")]
	public void InitMovementData(string path)
	{
		CSVData csvdata = new CSVData(path);
		int num = 0;
		float @float = csvdata.GetFloat(1, num);
		this.walkSpeed = @float;
		float float2 = csvdata.GetFloat(1, 1);
		this.runSpeed = float2;
		float float3 = csvdata.GetFloat(1, 2);
		this.dashSpeed = float3;
		float float4 = csvdata.GetFloat(1, 3);
		this.aimSpeed = float4;
		float float5 = csvdata.GetFloat(1, 4);
		this.shotSpeed = float5;
		float float6 = csvdata.GetFloat(1, 5);
		this.dodgeSpeedForward = float6;
		float float7 = csvdata.GetFloat(1, 6);
		this.dodgeSpeedBack = float7;
		int num2 = 0;
		float float8 = csvdata.GetFloat(3, num2);
		this.dashAttackSpeed = float8;
	}

	// Token: 0x06001CB6 RID: 7350 RVA: 0x00044A64 File Offset: 0x00042C64
	[Token(Token = "0x6001CB6")]
	[Address(RVA = "0xECC870", Offset = "0xECB670", VA = "0x180ECC870")]
	public void InitAttackData(string path)
	{
		CSVData csvdata = new CSVData(path);
		int rowLength = csvdata.GetRowLength();
		this.attackDataLimit = rowLength;
		float[] allFloatValues = this.GetAllFloatValues(csvdata, "WaitTime");
		this.attackWaitTimes = allFloatValues;
		float[] allFloatValues2 = this.GetAllFloatValues(csvdata, "NextTime");
		this.attackNextTimes = allFloatValues2;
		float[] allFloatValues3 = this.GetAllFloatValues(csvdata, "NextEndTime");
		this.attackNextEndTimes = allFloatValues3;
		float[] allFloatValues4 = this.GetAllFloatValues(csvdata, "FreeTime");
		this.attackFreeTimes = allFloatValues4;
		float[] allFloatValues5 = this.GetAllFloatValues(csvdata, "DeltaTime");
		this.attackDeltaTimes = allFloatValues5;
		float[] allFloatValues6 = this.GetAllFloatValues(csvdata, "DeltaTime2");
		this.attackDelta2Times = allFloatValues6;
		float[] allFloatValues7 = this.GetAllFloatValues(csvdata, "MoveTime");
		this.attackMoveTimes = allFloatValues7;
		float[] allFloatValues8 = this.GetAllFloatValues(csvdata, "MoveTime2");
		this.attackMove2Times = allFloatValues8;
		float[] allFloatValues9 = this.GetAllFloatValues(csvdata, "MoveSpeed");
		this.attackMoveSpeed = allFloatValues9;
		float[] allFloatValues10 = this.GetAllFloatValues(csvdata, "MoveSpeed2");
		this.attackMoveSpeed2 = allFloatValues10;
		int rowLength2 = csvdata.GetRowLength();
		int[] array = new int[rowLength2];
		int num = 0;
		if (rowLength2 > 0)
		{
			int num2 = Animator.StringToHash(csvdata.GetString("AniName", num));
			num++;
			array[0] = num2;
		}
		this.attackAnimationHashes = array;
		throw new NullReferenceException();
	}

	// Token: 0x06001CB7 RID: 7351 RVA: 0x00044BA8 File Offset: 0x00042DA8
	[Token(Token = "0x6001CB7")]
	[Address(RVA = "0xECC770", Offset = "0xECB570", VA = "0x180ECC770")]
	public void InitAirAttackData(string path)
	{
		/*
An exception occurred when decompiling this method (06001CB7)

ICSharpCode.Decompiler.DecompilerException: Error decompiling System.Void NobetaConfigData::InitAirAttackData(System.String)

 ---> System.Exception: Basic block has to end with unconditional control flow. 
{; 	Block_0:; 	stloc:CSVData(var_0_06, newobj:CSVData(CSVData::.ctor, ldloc:string(path))); 	stloc:float32[](var_1_13, call:float32[](NobetaConfigData::GetAllFloatValues, ldloc:NobetaConfigData(this), ldloc:CSVData(var_0_06), ldstr:string("WaitTime"))); 	stfld:float32[](NobetaConfigData::airAttackWaitTimes, ldloc:NobetaConfigData(this), ldloc:float32[](var_1_13)); 	stloc:float32[](var_2_27, call:float32[](NobetaConfigData::GetAllFloatValues, ldloc:NobetaConfigData(this), ldloc:CSVData(var_0_06), ldstr:string("NextTime"))); 	stfld:float32[](NobetaConfigData::airAttackNextTimes, ldloc:NobetaConfigData(this), ldloc:float32[](var_2_27)); 	stloc:float32[](var_3_3B, call:float32[](NobetaConfigData::GetAllFloatValues, ldloc:NobetaConfigData(this), ldloc:CSVData(var_0_06), ldstr:string("NextEndTime"))); 	stfld:float32[](NobetaConfigData::airAttackNextEndTimes, ldloc:NobetaConfigData(this), ldloc:float32[](var_3_3B)); }; 
   at ICSharpCode.Decompiler.ILAst.ILAstOptimizer.FlattenBasicBlocks(ILNode node) in D:\a\dnSpy\dnSpy\Extensions\ILSpy.Decompiler\ICSharpCode.Decompiler\ICSharpCode.Decompiler\ILAst\ILAstOptimizer.cs:line 1810
   at ICSharpCode.Decompiler.ILAst.ILAstOptimizer.Optimize(DecompilerContext context, ILBlock method, AutoPropertyProvider autoPropertyProvider, StateMachineKind& stateMachineKind, MethodDef& inlinedMethod, AsyncMethodDebugInfo& asyncInfo, ILAstOptimizationStep abortBeforeStep) in D:\a\dnSpy\dnSpy\Extensions\ILSpy.Decompiler\ICSharpCode.Decompiler\ICSharpCode.Decompiler\ILAst\ILAstOptimizer.cs:line 344
   at ICSharpCode.Decompiler.Ast.AstMethodBodyBuilder.CreateMethodBody(IEnumerable`1 parameters, MethodDebugInfoBuilder& builder) in D:\a\dnSpy\dnSpy\Extensions\ILSpy.Decompiler\ICSharpCode.Decompiler\ICSharpCode.Decompiler\Ast\AstMethodBodyBuilder.cs:line 123
   at ICSharpCode.Decompiler.Ast.AstMethodBodyBuilder.CreateMethodBody(MethodDef methodDef, DecompilerContext context, AutoPropertyProvider autoPropertyProvider, IEnumerable`1 parameters, Boolean valueParameterIsKeyword, StringBuilder sb, MethodDebugInfoBuilder& stmtsBuilder) in D:\a\dnSpy\dnSpy\Extensions\ILSpy.Decompiler\ICSharpCode.Decompiler\ICSharpCode.Decompiler\Ast\AstMethodBodyBuilder.cs:line 88
   --- End of inner exception stack trace ---
   at ICSharpCode.Decompiler.Ast.AstMethodBodyBuilder.CreateMethodBody(MethodDef methodDef, DecompilerContext context, AutoPropertyProvider autoPropertyProvider, IEnumerable`1 parameters, Boolean valueParameterIsKeyword, StringBuilder sb, MethodDebugInfoBuilder& stmtsBuilder) in D:\a\dnSpy\dnSpy\Extensions\ILSpy.Decompiler\ICSharpCode.Decompiler\ICSharpCode.Decompiler\Ast\AstMethodBodyBuilder.cs:line 92
   at ICSharpCode.Decompiler.Ast.AstBuilder.AddMethodBody(EntityDeclaration methodNode, EntityDeclaration& updatedNode, MethodDef method, IEnumerable`1 parameters, Boolean valueParameterIsKeyword, MethodKind methodKind) in D:\a\dnSpy\dnSpy\Extensions\ILSpy.Decompiler\ICSharpCode.Decompiler\ICSharpCode.Decompiler\Ast\AstBuilder.cs:line 1618
*/;
	}

	// Token: 0x06001CB8 RID: 7352 RVA: 0x000020D3 File Offset: 0x000002D3
	[Token(Token = "0x6001CB8")]
	[Address(RVA = "0xECC340", Offset = "0xECB140", VA = "0x180ECC340")]
	private float[] GetAllFloatValues(CSVData data, string propertyName)
	{
		throw new AnalysisFailedException("CPP2IL failed to recover any usable IL for this method.");
	}

	// Token: 0x06001CB9 RID: 7353 RVA: 0x00044BF8 File Offset: 0x00042DF8
	[Token(Token = "0x6001CB9")]
	[Address(RVA = "0xECC270", Offset = "0xECB070", VA = "0x180ECC270")]
	private int[] GetAllAnimationHashes(CSVData data, string propertyName)
	{
		int rowLength = data.GetRowLength();
		int[] array = new int[rowLength];
		int num = 0;
		if (rowLength > 0)
		{
			int num2 = Animator.StringToHash(data.GetString(propertyName, num));
			num++;
			array[0] = num2;
		}
		return array;
	}

	// Token: 0x06001CBA RID: 7354 RVA: 0x00044C3C File Offset: 0x00042E3C
	[Token(Token = "0x6001CBA")]
	[Address(RVA = "0x42E050", Offset = "0x42CE50", VA = "0x18042E050")]
	public float GetWalkSpeed()
	{
		return this.walkSpeed;
	}

	// Token: 0x06001CBB RID: 7355 RVA: 0x00044C50 File Offset: 0x00042E50
	[Token(Token = "0x6001CBB")]
	[Address(RVA = "0x5615F0", Offset = "0x5603F0", VA = "0x1805615F0")]
	public float GetRunSpeed()
	{
		return this.runSpeed;
	}

	// Token: 0x06001CBC RID: 7356 RVA: 0x00044C64 File Offset: 0x00042E64
	[Token(Token = "0x6001CBC")]
	[Address(RVA = "0x603D30", Offset = "0x602B30", VA = "0x180603D30")]
	public float GetDashSpeed()
	{
		return this.dashSpeed;
	}

	// Token: 0x06001CBD RID: 7357 RVA: 0x00044C78 File Offset: 0x00042E78
	[Token(Token = "0x6001CBD")]
	[Address(RVA = "0x5B5B10", Offset = "0x5B4910", VA = "0x1805B5B10")]
	public float GetAimSpeed()
	{
		return this.aimSpeed;
	}

	// Token: 0x06001CBE RID: 7358 RVA: 0x00044C8C File Offset: 0x00042E8C
	[Token(Token = "0x6001CBE")]
	[Address(RVA = "0x3FBE40", Offset = "0x3FAC40", VA = "0x1803FBE40")]
	public float GetShotSpeed()
	{
		return this.shotSpeed;
	}

	// Token: 0x06001CBF RID: 7359 RVA: 0x00044CA0 File Offset: 0x00042EA0
	[Token(Token = "0x6001CBF")]
	[Address(RVA = "0x5B0660", Offset = "0x5AF460", VA = "0x1805B0660")]
	public float GetDodgeSpeedF()
	{
		return this.dodgeSpeedForward;
	}

	// Token: 0x06001CC0 RID: 7360 RVA: 0x00044CB4 File Offset: 0x00042EB4
	[Token(Token = "0x6001CC0")]
	[Address(RVA = "0x5F9910", Offset = "0x5F8710", VA = "0x1805F9910")]
	public float GetDodgeSpeedB()
	{
		return this.dodgeSpeedBack;
	}

	// Token: 0x06001CC1 RID: 7361 RVA: 0x00044CC8 File Offset: 0x00042EC8
	[Token(Token = "0x6001CC1")]
	[Address(RVA = "0x6969C0", Offset = "0x6957C0", VA = "0x1806969C0")]
	public float GetDashAttackSpeed()
	{
		return this.dashAttackSpeed;
	}

	// Token: 0x06001CC2 RID: 7362 RVA: 0x00044CDC File Offset: 0x00042EDC
	[Token(Token = "0x6001CC2")]
	[Address(RVA = "0x58EB10", Offset = "0x58D910", VA = "0x18058EB10")]
	public void UpdateAttackIndex(int index)
	{
		this.attackIndex = index;
	}

	// Token: 0x06001CC3 RID: 7363 RVA: 0x00044CF0 File Offset: 0x00042EF0
	[Token(Token = "0x6001CC3")]
	[Address(RVA = "0xECC730", Offset = "0xECB530", VA = "0x180ECC730")]
	public float GetAttackWaitTime()
	{
		float[] array = this.attackWaitTimes;
		int num = this.attackIndex;
		return array[num];
	}

	// Token: 0x06001CC4 RID: 7364 RVA: 0x00044D18 File Offset: 0x00042F18
	[Token(Token = "0x6001CC4")]
	[Address(RVA = "0xECC6D0", Offset = "0xECB4D0", VA = "0x180ECC6D0")]
	public float GetAttackWaitTimeMinusNextTime()
	{
		float[] array = this.attackWaitTimes;
		int num = this.attackIndex;
		float num2 = array[num];
		float[] array2 = this.attackNextTimes;
		return num2;
	}

	// Token: 0x06001CC5 RID: 7365 RVA: 0x00044D4C File Offset: 0x00042F4C
	[Token(Token = "0x6001CC5")]
	[Address(RVA = "0xECC670", Offset = "0xECB470", VA = "0x180ECC670")]
	public float GetAttackWaitTimeMinusFreeTime()
	{
		float[] array = this.attackWaitTimes;
		int num = this.attackIndex;
		float num2 = array[num];
		float[] array2 = this.attackFreeTimes;
		return num2;
	}

	// Token: 0x06001CC6 RID: 7366 RVA: 0x00044D80 File Offset: 0x00042F80
	[Token(Token = "0x6001CC6")]
	[Address(RVA = "0xECC610", Offset = "0xECB410", VA = "0x180ECC610")]
	public float GetAttackWaitTimeMinusDelta2Time()
	{
		float[] array = this.attackWaitTimes;
		int num = this.attackIndex;
		float num2 = array[num];
		float[] array2 = this.attackDelta2Times;
		return num2;
	}

	// Token: 0x06001CC7 RID: 7367 RVA: 0x00044DB4 File Offset: 0x00042FB4
	[Token(Token = "0x6001CC7")]
	[Address(RVA = "0xECC5D0", Offset = "0xECB3D0", VA = "0x180ECC5D0")]
	public float GetAttackNextEndTime()
	{
		float[] array = this.attackNextEndTimes;
		int num = this.attackIndex;
		return array[num];
	}

	// Token: 0x06001CC8 RID: 7368 RVA: 0x00044DDC File Offset: 0x00042FDC
	[Token(Token = "0x6001CC8")]
	[Address(RVA = "0xECC490", Offset = "0xECB290", VA = "0x180ECC490")]
	public float GetAttackDeltaTime()
	{
		float[] array = this.attackDeltaTimes;
		int num = this.attackIndex;
		return array[num];
	}

	// Token: 0x06001CC9 RID: 7369 RVA: 0x00044E04 File Offset: 0x00043004
	[Token(Token = "0x6001CC9")]
	[Address(RVA = "0xECC450", Offset = "0xECB250", VA = "0x180ECC450")]
	public float GetAttackDelta2Time()
	{
		float[] array = this.attackDelta2Times;
		int num = this.attackIndex;
		return array[num];
	}

	// Token: 0x06001CCA RID: 7370 RVA: 0x00044E2C File Offset: 0x0004302C
	[Token(Token = "0x6001CCA")]
	[Address(RVA = "0xECC590", Offset = "0xECB390", VA = "0x180ECC590")]
	public float GetAttackMoveTime()
	{
		float[] array = this.attackMoveTimes;
		int num = this.attackIndex;
		return array[num];
	}

	// Token: 0x06001CCB RID: 7371 RVA: 0x00044E54 File Offset: 0x00043054
	[Token(Token = "0x6001CCB")]
	[Address(RVA = "0xECC4D0", Offset = "0xECB2D0", VA = "0x180ECC4D0")]
	public float GetAttackMove2Time()
	{
		float[] array = this.attackMove2Times;
		int num = this.attackIndex;
		return array[num];
	}

	// Token: 0x06001CCC RID: 7372 RVA: 0x00044E7C File Offset: 0x0004307C
	[Token(Token = "0x6001CCC")]
	[Address(RVA = "0xECC550", Offset = "0xECB350", VA = "0x180ECC550")]
	public float GetAttackMoveSpeed()
	{
		float[] array = this.attackMoveSpeed;
		int num = this.attackIndex;
		return array[num];
	}

	// Token: 0x06001CCD RID: 7373 RVA: 0x00044EA4 File Offset: 0x000430A4
	[Token(Token = "0x6001CCD")]
	[Address(RVA = "0xECC510", Offset = "0xECB310", VA = "0x180ECC510")]
	public float GetAttackMoveSpeed2()
	{
		float[] array = this.attackMoveSpeed2;
		int num = this.attackIndex;
		return array[num];
	}

	// Token: 0x06001CCE RID: 7374 RVA: 0x00044ECC File Offset: 0x000430CC
	[Token(Token = "0x6001CCE")]
	[Address(RVA = "0xECC410", Offset = "0xECB210", VA = "0x180ECC410")]
	public int GetAttackAnimationHash()
	{
		int[] array = this.attackAnimationHashes;
		int num = this.attackIndex;
		return array[num];
	}

	// Token: 0x06001CCF RID: 7375 RVA: 0x00044EF4 File Offset: 0x000430F4
	[Token(Token = "0x6001CCF")]
	[Address(RVA = "0xECCBA0", Offset = "0xECB9A0", VA = "0x180ECCBA0")]
	public void InitAttackIndex()
	{
		if (this.attackIndex < 1)
		{
			this.attackIndex = (int)((ulong)1L);
		}
	}

	// Token: 0x06001CD0 RID: 7376 RVA: 0x000020D3 File Offset: 0x000002D3
	[Token(Token = "0x6001CD0")]
	[Address(RVA = "0xECCCE0", Offset = "0xECBAE0", VA = "0x180ECCCE0")]
	public bool TryIncreaseAttackIndex()
	{
		throw new AnalysisFailedException("CPP2IL failed to recover any usable IL for this method.");
	}

	// Token: 0x06001CD1 RID: 7377 RVA: 0x00044F14 File Offset: 0x00043114
	[Token(Token = "0x6001CD1")]
	[Address(RVA = "0x417BA0", Offset = "0x4169A0", VA = "0x180417BA0")]
	public void UpdateAirAttackIndex(int index)
	{
		this.airAttackIndex = index;
	}

	// Token: 0x06001CD2 RID: 7378 RVA: 0x00044F28 File Offset: 0x00043128
	[Token(Token = "0x6001CD2")]
	[Address(RVA = "0xECC230", Offset = "0xECB030", VA = "0x180ECC230")]
	public float GetAirAttackWaitTime()
	{
		float[] array = this.airAttackWaitTimes;
		int num = this.airAttackIndex;
		return array[num];
	}

	// Token: 0x06001CD3 RID: 7379 RVA: 0x00044F50 File Offset: 0x00043150
	[Token(Token = "0x6001CD3")]
	[Address(RVA = "0xECC1C0", Offset = "0xECAFC0", VA = "0x180ECC1C0")]
	public float GetAirAttackWaitTimeMinusNextTime()
	{
		float[] array = this.airAttackWaitTimes;
		int num = this.airAttackIndex;
		float num2 = array[num];
		float[] array2 = this.airAttackNextTimes;
		return num2;
	}

	// Token: 0x06001CD4 RID: 7380 RVA: 0x00044F84 File Offset: 0x00043184
	[Token(Token = "0x6001CD4")]
	[Address(RVA = "0xECC180", Offset = "0xECAF80", VA = "0x180ECC180")]
	public float GetAirAttackNextEndTime()
	{
		float[] array = this.airAttackNextEndTimes;
		int num = this.airAttackIndex;
		return array[num];
	}

	// Token: 0x06001CD5 RID: 7381 RVA: 0x00044FAC File Offset: 0x000431AC
	[Token(Token = "0x6001CD5")]
	[Address(RVA = "0x3D8B20", Offset = "0x3D7920", VA = "0x1803D8B20")]
	public NobetaConfigData()
	{
	}

	// Token: 0x040025CC RID: 9676
	[FieldOffset(Offset = "0x10")]
	[Token(Token = "0x40025CC")]
	[SerializeField]
	private float walkSpeed;

	// Token: 0x040025CD RID: 9677
	[FieldOffset(Offset = "0x14")]
	[Token(Token = "0x40025CD")]
	[SerializeField]
	private float runSpeed;

	// Token: 0x040025CE RID: 9678
	[FieldOffset(Offset = "0x18")]
	[Token(Token = "0x40025CE")]
	[SerializeField]
	private float dashSpeed;

	// Token: 0x040025CF RID: 9679
	[FieldOffset(Offset = "0x1C")]
	[Token(Token = "0x40025CF")]
	[SerializeField]
	private float aimSpeed;

	// Token: 0x040025D0 RID: 9680
	[FieldOffset(Offset = "0x20")]
	[Token(Token = "0x40025D0")]
	[SerializeField]
	private float shotSpeed;

	// Token: 0x040025D1 RID: 9681
	[FieldOffset(Offset = "0x24")]
	[Token(Token = "0x40025D1")]
	[SerializeField]
	private float dodgeSpeedForward;

	// Token: 0x040025D2 RID: 9682
	[FieldOffset(Offset = "0x28")]
	[Token(Token = "0x40025D2")]
	[SerializeField]
	private float dodgeSpeedBack;

	// Token: 0x040025D3 RID: 9683
	[FieldOffset(Offset = "0x2C")]
	[Token(Token = "0x40025D3")]
	[SerializeField]
	private float dashAttackSpeed;

	// Token: 0x040025D4 RID: 9684
	[FieldOffset(Offset = "0x30")]
	[Token(Token = "0x40025D4")]
	[SerializeField]
	private int attackIndex;

	// Token: 0x040025D5 RID: 9685
	[FieldOffset(Offset = "0x34")]
	[Token(Token = "0x40025D5")]
	[SerializeField]
	private int attackDataLimit;

	// Token: 0x040025D6 RID: 9686
	[FieldOffset(Offset = "0x38")]
	[Token(Token = "0x40025D6")]
	[SerializeField]
	private float[] attackWaitTimes;

	// Token: 0x040025D7 RID: 9687
	[FieldOffset(Offset = "0x40")]
	[Token(Token = "0x40025D7")]
	[SerializeField]
	private float[] attackNextTimes;

	// Token: 0x040025D8 RID: 9688
	[FieldOffset(Offset = "0x48")]
	[Token(Token = "0x40025D8")]
	[SerializeField]
	private float[] attackNextEndTimes;

	// Token: 0x040025D9 RID: 9689
	[FieldOffset(Offset = "0x50")]
	[Token(Token = "0x40025D9")]
	[SerializeField]
	private float[] attackFreeTimes;

	// Token: 0x040025DA RID: 9690
	[FieldOffset(Offset = "0x58")]
	[Token(Token = "0x40025DA")]
	[SerializeField]
	private float[] attackDeltaTimes;

	// Token: 0x040025DB RID: 9691
	[FieldOffset(Offset = "0x60")]
	[Token(Token = "0x40025DB")]
	[SerializeField]
	private float[] attackDelta2Times;

	// Token: 0x040025DC RID: 9692
	[FieldOffset(Offset = "0x68")]
	[Token(Token = "0x40025DC")]
	[SerializeField]
	private float[] attackMoveTimes;

	// Token: 0x040025DD RID: 9693
	[FieldOffset(Offset = "0x70")]
	[Token(Token = "0x40025DD")]
	[SerializeField]
	private float[] attackMove2Times;

	// Token: 0x040025DE RID: 9694
	[FieldOffset(Offset = "0x78")]
	[Token(Token = "0x40025DE")]
	[SerializeField]
	private float[] attackMoveSpeed;

	// Token: 0x040025DF RID: 9695
	[FieldOffset(Offset = "0x80")]
	[Token(Token = "0x40025DF")]
	[SerializeField]
	private float[] attackMoveSpeed2;

	// Token: 0x040025E0 RID: 9696
	[FieldOffset(Offset = "0x88")]
	[Token(Token = "0x40025E0")]
	[SerializeField]
	private int[] attackAnimationHashes;

	// Token: 0x040025E1 RID: 9697
	[FieldOffset(Offset = "0x90")]
	[Token(Token = "0x40025E1")]
	[SerializeField]
	private int airAttackIndex;

	// Token: 0x040025E2 RID: 9698
	[FieldOffset(Offset = "0x98")]
	[Token(Token = "0x40025E2")]
	[SerializeField]
	private float[] airAttackWaitTimes;

	// Token: 0x040025E3 RID: 9699
	[FieldOffset(Offset = "0xA0")]
	[Token(Token = "0x40025E3")]
	[SerializeField]
	private float[] airAttackNextTimes;

	// Token: 0x040025E4 RID: 9700
	[FieldOffset(Offset = "0xA8")]
	[Token(Token = "0x40025E4")]
	[SerializeField]
	private float[] airAttackNextEndTimes;
}
